@@ -1,7 +1,7 @@
 use std::cmp;
 
-use pair::step_mask::StepMask;
-use pair::strategy::Strategy;
+use crate::pair::step_mask::StepMask;
+use crate::pair::strategy::Strategy;
 
 #[derive(Clone, Debug)]
 pub struct SmithWaterman {
